@@ -24,5 +24,5 @@ class MinutesWidget(TextInput):
     def divide(cls, total):
         if total <= 0:
             return (0, 0)
-        hours = 0 if total <= 60 else total / 60
+        hours = 0 if total < 60 else total / 60
         return (hours, total - (hours * 60))
